<?php
if ( ! class_exists('BanglaPress_core'))
{
	/**
	 * The core BanglaPress class where the magic happens
	 *
	 * @package BanglaPress
	 * @since 1.0
	 */
	class BanglaPress_core {
		
		/**
		 * Calls the method to create admin menus and to set up the admin area
		 *
		 * @package BanglaPress
		 * @since 1.0
		 */
		function create_admin()
		{
			// Action to initiate the admin setup and admin menu setup
			add_action('admin_menu', array(&$this, 'load_admin'));
		}
		
		/**
		 * Loads the install class and setups the plugin including database creation
		 *
		 * @package BanglaPress
		 * @since 1.0
		 */
		function load_activation()
		{
			require_once(MOPR_PATH . 'classes/install.php');
			$install = new BanglaPress_install;
		}
		
		/**
		 * Creates the BanglaPress menus and creates an admin object which creates the menu content
		 *
		 * @package BanglaPress
		 * @since 1.0
		 */
		function load_admin()
		{
			require_once(MOPR_PATH . 'classes/admin.php');
			
			$BanglaPress_admin = new BanglaPress_admin;
			
			// Add admin 'BanglaPress' to the top level menu area
			add_menu_page('BanglaPress', 'BanglaPress', 10, 'Banglapress', '', WP_PLUGIN_URL . '/Banglapress/system/views/images/icon.png');
			
				//Add the 'Options' submenu to the BanglaPress menu and render the page
				add_submenu_page('Banglapress', 'BanglaPress Options', 'Options', 10, 'Banglapress', array(&$BanglaPress_admin, 'render_options'));
				
				//Add the 'Themes' submenu to the BanglaPress menu and render the page
				add_submenu_page('Banglapress', 'BanglaPress Themes', 'Themes', 10, 'Banglapress-themes', array(&$BanglaPress_admin, 'render_themes'));
				
				//Add the 'Ads' submenu to the BanglaPress menu and render the page
				add_submenu_page('Banglapress', 'BanglaPress Ads', 'Bangla Press Info', 10, 'Banglapress-ads', array(&$BanglaPress_admin, 'render_ads'));
		}
		
		/**
		 * Deactivates the plugin
		 *
		 * @package BanglaPress
		 * @since 1.0
		 */
		function load_deactivation()
		{
			// Shutdown the plugin (nothing here yet)
		}
		
		/**
		 * Does the checks and decides whether to render a Bangla or normal website
		 *
		 * @package BanglaPress
		 * @since 1.0
		 */
		function load_site()
		{
			if (isset($_GET['killsession']))
			{
				session_unset();
				session_destroy();
			}
			
			// Plugin preference is set to render entire site in Bangla.
			if (mopr_get_option('force_Bangla', 1))
			{
				$_SESSION['MOPR_Bangla_ACTIVE'] = TRUE;
			}
			
			// Check if Bangla sesison var exists
			// Also, check if ?Bangla or ?noBangla is set. If so, establish the session var so that subsequent page calls will render in the desired mode.
			if (( ! isset($_SESSION['MOPR_Bangla_ACTIVE']) || (trim($_SESSION['MOPR_Bangla_ACTIVE']) == '')) || (isset($_GET['Bangla'])) || (isset($_GET['noBangla'])))
			{
				// If the session var doesn't exist, proceed to init and check to see if we are dealing with a Bangla browser
				require_once(MOPR_PATH . 'classes/check.php');
				$checkBangla = new BanglaPress_check;
				$checkBangla->init();
			}
			
			// Set the browser variable
			$browser = $_SESSION['MOPR_Bangla_BROWSER'];
			
			// This is for testing Bangla themes in a normal browser and Bangla browsers, resets browser session if you are switching between Bangla browsers
			if ((isset($_GET['Bangla']) && ($browser != "Bangla")) || (isset($_GET['iphone']) && ($browser != "iphone")))
			{
				require_once(MOPR_PATH . 'classes/check.php');
				$checkBangla = new BanglaPress_check;
				$checkBangla->init();
				
				// Reset the browser variable
				$browser = $_SESSION['MOPR_Bangla_BROWSER'];
			}
			
			if ($_SESSION['MOPR_Bangla_ACTIVE'] === TRUE)
			{
				// Double check session var for theme, fall back on default if any problems
				if ( ! isset($_SESSION['MOPR_Bangla_THEME']) || (trim($_SESSION['MOPR_Bangla_THEME']) == ''))
				{
					$_SESSION['MOPR_Bangla_THEME'] = mopr_get_option('default_theme', 1);
				}

				// Render time!
				require_once(MOPR_PATH . 'classes/render.php');
				$render = new BanglaPress_render();
				$render->init();
			}
			else
			{
				// MOPR_Bangla_ACTIVE has explicitly been set to false. Either by following noBangla link, or there were no matches in the detection script (We're using a web browser)
			}
		}

	}
}
?>