<?php
if ( ! class_exists('BanglaPress_render'))
{
	/**
	 * Class that deals with all aspects of rendering the Bangla website
	 *
	 * @package BanglaPress
	 * @since 1.0
	 */
	class BanglaPress_render {
	
		/**
		 * @var string $default_theme The default Bangla theme
		 */
		var $default_theme;
		
		/**
		 * @var string $title The title of the Bangla blog
		 */
		var $title;
		
		/**
		 * @var string $description The description of the Bangla blog
		 */
		var $description;
		
		/**
		 * Constructor which sets up the variables we will need to use
		 *
		 * @package BanglaPress
		 * @since 1.0
		 * @param STRING $browser The browser to render for
		 */
		function BanglaPress_render()
		{
			$this->default_theme	= mopr_get_option('default_theme', 1);
			$this->title			= mopr_get_option('title', 1);
			$this->description		= mopr_get_option('description', 1);
		}
		
		/**
		 * Initialize the rendering of the Bangla website
		 *
		 * @package BanglaPress
		 * @since 1.0
		 */
		function init()
		{	
			add_filter('stylesheet', array(&$this, 'set_stylesheet'));
			add_filter('theme_root', array(&$this, 'set_theme_root'));
			add_filter('theme_root_uri', array(&$this, 'set_theme_uri'));
			add_filter('template', array(&$this, 'set_template'));
			
			if ($this->title != '')
			{
				add_filter('option_blogname', array(&$this, 'set_title'));
			}
			
			if ($this->description != '')
			{
				add_filter('option_blogdescription', array(&$this, 'set_description'));
			}
		}
		
		/**
		 * Returns the Bangla blogs description
		 *
		 * @package BanglaPress
		 * @since 1.0
		 * @return STRING The Bangla blogs description
		 */
		function set_description()
		{
			return $this->description;
		}
		
		/**
		 * Sets the stylesheet to the themes Bangla stylesheet
		 *
		 * @package BanglaPress
		 * @since 1.0
		 * @return STRING Name of the theme where the stylesheet will be called
		 */
		function set_stylesheet()
		{	
			if ( ! isset($_SESSION['MOPR_Bangla_THEME']) || trim($_SESSION['MOPR_Bangla_THEME']) == '')
			{
				$stylesheet = $this->default_theme;
			}
			else
			{
				$stylesheet = $_SESSION['MOPR_Bangla_THEME'];
			}
			
			return $stylesheet;
		}
		
		/**
		 * Sets the blogs template to the BanglaPress template
		 *
		 * @package BanglaPress
		 * @since 1.0
		 * @return STRING The name of the BanglaPress template to be used for rendering
		 */
		function set_template()
		{
			if ( ! isset($_SESSION['MOPR_Bangla_THEME']) || trim($_SESSION['MOPR_Bangla_THEME']) == '')
			{
				$template = $this->default_theme;
			}
			else
			{
				$template = $_SESSION['MOPR_Bangla_THEME'];
			}
			
			return $template;
		}
		
		/**
		 * Sets the theme root to the BanglaPress theme directory
		 *
		 * @package BanglaPress
		 * @since 1.0
		 * @return STRING Root directory of the BanglaPress theme directory
		 */
		function set_theme_root()
		{
			if ( ! isset($_SESSION['MOPR_Bangla_THEME']) || trim($_SESSION['MOPR_Bangla_THEME']) == '')
			{
				$template = $this->default_theme;
			}
			else
			{
				$template = $_SESSION['MOPR_Bangla_THEME'];
			}
			
			if ($template == 'default' || $template == 'iphone')
			{
				return MOPR_ROOT_PATH . "system/themes";
			}
			else
			{
				return rtrim(WP_CONTENT_DIR, '/') . '/' . mopr_get_option('themes_directory', 1);
			}
		}
		
		/**
		 * Sets the path to the themes directory
		 *
		 * @package BanglaPress
		 * @since 1.0
		 * @return STRING The BanglaPress theme directory
		 */
		function set_theme_uri()
		{
			if ( ! isset($_SESSION['MOPR_Bangla_THEME']) || trim($_SESSION['MOPR_Bangla_THEME']) == '')
			{
				$template = $this->default_theme;
			}
			else
			{
				$template = $_SESSION['MOPR_Bangla_THEME'];
			}
			
			if ($template == 'default' || $template == 'iphone')
			{
				return get_bloginfo('wpurl') . "/wp-content/plugins/Banglapress/system/themes";
			}
			else
			{
				return get_bloginfo('wpurl') . "/wp-content/" . mopr_get_option('themes_directory', 1);
			}
		}
		
		/**
		 * Returns the Bangla blogs title
		 *
		 * @package BanglaPress
		 * @since 1.0
		 * @return STRING The Bangla blogs title
		 */
		function set_title()
		{
			return $this->title;
		}
		
	}
}
?>